
To quickly look up common chemicals & their prices, for "the big 3":
- Sigma-Aldrich (MilliporeSigma): https://www.sigmaaldrich.com/US/en/products/chemistry-and-biochemicals/lab-chemicals
- Fisher Scientific (Thermo Fisher Scientific): https://www.thermofisher.com/us/en/home/chemicals.html
- VWR International (Avantor): https://www.avantorsciences.com/us/en/products/chemicals
